@@ -322,6 +322,12 @@ set_area (GsdWacomDevice  *device,
             property.data.i[3] == -1) {
                 gint *area;
                 area = gsd_wacom_device_get_default_area (device);
+
+                if (!area) {
+                        g_warning ("No default area could be obtained from the device");
+                        return;
+                }
+
                 property.data.i = area;
                 g_debug ("Resetting area to: %d, %d, %d, %d",
                          property.data.i[0],
